#!/bin/sh
# /usr/local/MRUF-lst/bin/verse-reverse.sh
#
# Other possible locations for this script: /root/my-applications/bin,
# ....................................................................... /opt/local/bin, or /usr/local/bin.
#
#
# Goal: do and undo a change concerning the GTK2 theme in files
# ------- defaulttextviewer, etc., all located in /usr/local/bin.
#
#
# Explanation: This may be desirable in the context of the MRUF-lst app,
# ----------------- where the above apps may show in a different theme than
# the system-wide theme the user chose. Applying the "replaceit" lines below,
# these "default" apps will retain their original GTK2 appearance even if
# run from within the MRUF-lst app. Back-ups of the originals are made.
#
# File /root/.gtkrc-2.0 (please see replaceit lines) contains the user's original choice
# of theme and font. By specifying it within the file, we retain the user's choice
# throughout the MRUF-lst session. as well as during normal operations.
# ----------------------------------------------------------------------------------------------------
#
# Note: This script must be made executable before running it.
# -------
#
#
# Usage:
# ---------
# To undo the change: Open a console and type < verse-reverse.sh undo >
# ----------------------------  (without the chevrons).
#
# To redo the change:  Open a console and type < verse-reverse.sh do >
# ---------------------------- (without the chevrons).
#
#
# (c) Christian L'Écuyer, Gatineau (Qc), Canada,  11 August 2017. GPL3.
# (Alias « musher0 » [forum Puppy].) https://opensource.org/licenses/GPL-3.0
#
####
A="$1"
DirBkp="$PWD" # Remembers the current dir (where you are).
cd /usr/local/bin # moves to the directory where the files are.

case "$A" in do)
#		for type in text image;do
			for file in default*;do
				[ -f $file.bkp ] || cp -f $file $file.bkp
				replaceit --input=$file exec "GTK2_RC_FILES=/root/.gtkrc-2.0 exec" # change
				chmod +x $file
#			done
		done ;;

	undo)
#		for type in text image;do
			for file in default*;do
				[ -f $file.bkp ] || cp -f $file $file.bkp
				replaceit --input=$file "GTK2_RC_FILES=/root/.gtkrc-2.0 exec" exec # reverse the change
				chmod +x $file
#			done
		done ;;
esac

cd $DirBkp # Brings you back to the dir where you were.
